(setq package-lisp
      (assemble-list
       (when-feature (and mule wnn) "egg-leim")
       (when-feature (and mule wnn) "egg-kwnn-leim")
       (when-feature (and mule wnn) "egg-cwnn-leim")
       (when-feature mule "egg-sj3-leim")
))
